==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="az" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 yeni ismarıc</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>%1 qoşulur</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 qoşuldu</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 ayrıldı</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>%1 ilə bağlantı mümkün deyil, lütfən routerinizi və ya şəbəkə kabelinizi yoxlayın.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>%1 ilə bağlantı mümüken deyil, lütfən simsiz routerinizə yaxınlaşın</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Bağlantı alınmadı, %1 ilə bağlantı mümkün deyil, şifrə səhvdir</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>%1 ilə bağlantı üçün şifrə tələb olunur</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN şəbəkəsi tapılmadı</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Simli bağlantı</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Qoşulma nöqtəsi</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Təhlükəsizlik növü</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Aralıq</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>İnterfeys</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Şəbəkə maskası</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Birinci DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sürət</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Cihaz söndürülüb</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Qoşulub, lakin internetə giriş yoxdur</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlantı yoxdur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Şəbəkə kabeli çıxarılıb</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Qoşulur...</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Doğrulanır</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>İP ünvanları alınır</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Qoşuldu</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Bağlantı kəsildi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Uğursuz</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Ünvan alınır</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Simli şəbəkə</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Simli şəbəkəsi %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Simsiz şəbəkə %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Cihaz söndürülüb</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Şəbəkə kabeli çıxarılıb</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlantı yoxdur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Qoşulur...</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Qoşulub, lakin internetə giriş yoxdur</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Qoşulma alınmadı</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Simli bağlantını söndürmək</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Simli bağlantını qoşmaq</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Simsiz bağlantını söndürmək</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Simsiz bağlantını qoşmaq</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Şəbəkəni söndürmək</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Şəbəkəni qoşmaq</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Şəbəkə ayarları</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dss-network-plugin/translations/dss-network-plugin_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 yeni ismarıc</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Naqilli şəbəkə</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>%1 qoşulur</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 qoşuldu</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 ayrıldı</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>%1 ilə bağlantı mümkün deyil, lütfən routerinizi və ya şəbəkə kabelinizi yoxlayın.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>%1 ilə bağlantı mümüken deyil, lütfən simsiz routerinizə yaxınlaşın</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Bağlantı alınmadı, %1 ilə bağlantı mümkün deyil, şifrə səhvdir</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>%1 ilə bağlantı üçün şifrə tələb olunur</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN şəbəkəsi tapılmadı</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli şəbəkəyə qoşulun</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Qoşulun</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Ad (SSİD)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Qoşulma nöqtəsi</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Təhlükəsizlik növü</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Aralıq</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>İnterfeys</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Şəbəkə maskası</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Birinci DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sürət</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Cihaz söndürülüb</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Qoşulub, lakin internetə giriş yoxdur</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlantı yoxdur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Şəbəkə kabeli çıxarılıb</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Qoşulur...</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Doğrulanır</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>İP ünvanları alınır</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Qoşuldu</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Bağlantı kəsildi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Uğursuz</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Ünvan alınır</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Simli şəbəkə</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Simli şəbəkəsi %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Simsiz şəbəkə %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Cihaz söndürülüb</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Şəbəkə kabeli çıxarılıb</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlantı yoxdur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Qoşulur...</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Qoşulub, lakin internetə giriş yoxdur</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Qoşulma alınmadı</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Simli bağlantını söndürmək</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Simli bağlantını qoşmaq</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Simsiz bağlantını söndürmək</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Simsiz bağlantını qoşmaq</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Şəbəkəni söndürmək</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Şəbəkəni qoşmaq</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Şəbəkə ayarları</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Simli bağlantı</translation>
    </message>
</context>
</TS>
